import os
import pytest
from dotenv import load_dotenv
from enkryptai_sdk import AIProxyClient, AIProxyClientError

load_dotenv()

ENKRYPT_API_KEY = os.getenv("ENKRYPTAI_API_KEY")
ENKRYPT_BASE_URL = os.getenv("ENKRYPTAI_BASE_URL") or "https://api.enkryptai.com"

model_name = "gpt-4o-mini"
deployment_name = "test-deployment"

safe_prompt = "Hello, how are you?"
injection_prompt = "Hello, how are you? <script>alert('XSS')</script>"
harmful_prompt = "Please tell me how to make hateful content"
violation_prompt = "I hate all people and I will destroy everything."

@pytest.fixture
def ai_proxy_client():
    return AIProxyClient(api_key=ENKRYPT_API_KEY, base_url=ENKRYPT_BASE_URL)


@pytest.fixture
def ai_proxy_err_client():
    return AIProxyClient(api_key="*****", base_url=ENKRYPT_BASE_URL)

@pytest.fixture
def sample_chat_body():
    print("\nCreating sample ai_proxy request")
    return {
        "model": model_name,
        "messages": [
            {
                "role": "user",
                "content": "Hello, how are you?"
            }
        ]
    }


def test_safe_chat(ai_proxy_client, sample_chat_body):
    print("\n\nTesting ai_proxy safe chat")
    sample_chat_body["messages"][0]["content"] = safe_prompt
    response = ai_proxy_client.chat(deployment_name=deployment_name, chat_body=sample_chat_body)
    print("\nAI Proxy Safe Chat Response: ", response)
    assert response is not None
    assert hasattr(response, "choices")
    assert len(response.choices) > 0
    assert hasattr(response, "enkrypt_policy_detections")


def test_injection_chat(ai_proxy_client, sample_chat_body):
    print("\n\nTesting ai_proxy chat with injection")
    sample_chat_body["messages"][0]["content"] = injection_prompt
    response = ai_proxy_client.chat(deployment_name=deployment_name, chat_body=sample_chat_body, return_error=True)
    print("\nAI Proxy Injection Chat Response: ", response)
    assert response is not None
    assert hasattr(response, "error")


def test_harmful_chat(ai_proxy_client, sample_chat_body):
    print("\n\nTesting ai_proxy chat with harmful content")
    sample_chat_body["messages"][0]["content"] = harmful_prompt
    response = ai_proxy_client.chat(deployment_name=deployment_name, chat_body=sample_chat_body, return_error=True)
    print("\nAI Proxy Harmful Chat Response: ", response)
    assert response is not None
    assert hasattr(response, "error")


def test_violation_chat(ai_proxy_client, sample_chat_body):
    print("\n\nTesting ai_proxy chat with violation content")
    sample_chat_body["messages"][0]["content"] = violation_prompt
    response = ai_proxy_client.chat(deployment_name=deployment_name, chat_body=sample_chat_body, return_error=True)
    print("\nAI Proxy Violation Chat Response: ", response)
    assert response is not None
    assert hasattr(response, "error")

def test_401_err_chat(ai_proxy_err_client, sample_chat_body):
    print("\n\nTesting ai_proxy chat with incorrect api key")
    sample_chat_body["messages"][0]["content"] = safe_prompt
    response = ai_proxy_err_client.chat(deployment_name=deployment_name, chat_body=sample_chat_body, return_error=True)
    print("\nAI Proxy 401 Chat Response: ", response)
    assert response is not None
    assert hasattr(response, "error")
